@@ -21,10 +21,14 @@ def print_yaml_report(image):
 
 
 class YAML(generator.Generate):
-    def generate(self, image_obj_list):
+    def generate(self, image_obj_list, print_inclusive=False):
         '''Generate a yaml report'''
         report = formats.disclaimer_yaml.format(
             version_info=get_git_rev_or_version())
         for image in image_obj_list:
             report = report + print_yaml_report(image)
         return report
+
+    def generate_layer(self, layer):
+        """Generate a yaml report for the given layer object"""
+        return yaml.dump(layer.to_dict(), default_flow_style=False)
